set more off
clear
clear matrix
set linesize 120
set memory 5G
set matsize 11000
capture log close
log using threewaveXTREG, replace
   //     The RADHLW Health Belief model     what sociodemographics, BSI, NHP, and CS explains radhlw?
   //     Robert A. Yaffee Ph.D.  16 June 2010
use "C:\Users\ray2\CURRENTresearch\chornobylproj\dataVault\chsamplingSurvey\Data\Data\3waveData\chlonw6bobbkup", clear
save chlonw6bobbkup, replace
set more off
xtset id wave
xtdescribe


// age and period effects here

bysort wave: tabstat agew
gen meanage = .
replace meanage=28.38 if wave==1
replace meanage = 38.38 if wave==2
replace meanage= 50.38 if wave==3
label var meanage "Average age at wave"


/*
graph box agew, over(gender) over(wave) title(Age by period effects by gender) ytitle(Age of respondent) /// 
  subtitle(wave=period) note(n=281 in interim sample) asyvars
  graph save ageperiod.gph, replace
  graph export ageperiod.emf, replace
graph box agew, over(wave) title(Age by period effects) ytitle(Age of respondent) ///
  subtitle(wave=period) note(n=281 in interim sample) asyvars
  graph save ageperiodGender.gph, replace
  graph export ageperiodgender.emf, replace
line agegrp wave,title(Age and Period effects shown here)

longplot agew wave, title(Age and Period effects)
longplot radhlw wave, by(gender) title(Belief in health impact of Chornobyl)




// two dependent variables  (before testing for endogeneity)

gr box radhlw, over(wave) asyvars title(Percent health affected by Chornobyl radiation) subtitle(by wave) 
graph save radhlWave.gph, replace
graph export radhlwave.emf, replace

gr box radhlw, over(gender) over(wave) asyvars title(Percent health affected by Chornobyl radiation) ///
   subtitle(by wave by gender) 
   graph save radhlWG.gph, replace
   graph export radhlWG.emf, replace
 */ 
xtsum radhlw
xtab radhlw
xtsum radfmw

sort wave
bysort wave: tabstat radhlw, stat(mean median semean skewness kurtosis sd p1 p5 p25 p50 p75 p95 p99 n)
bysort wave: tabstat radfmw, stat(mean median semean skewness kurtosis sd p1 p5 p25 p50 p75 p95 p99 n)
//  we examine radhlw models first
sort wave
hist radhlw if wave==1,subtitle(wave one 1986)
gr save radhlw1.gph, replace
hist radhlw if wave==2, subtitle(wave 1996)
gr save radhlw2.gph, replace
hist radhlw if wave==3, subtitle(wave three now)
gr save radhlw3.gph, replace
gr combine radhlw1.gph radhlw2.gph radhlw3.gph, col(1) title(Percent of radiaton impact on own health) ///
 subtitle(Distributional change over waves)
graph save radhlw.gph, replace
graph export radhlw.emf, replace
sort wave
hist radhlw if wave==1 & gender==1,subtitle(wave one 1986 males) color(sienna)
gr save radhlw1m.gph, replace
hist radhlw if wave==1 & gender==2,subtitle(wave one 1986 females)
gr save radhlw1f.gph, replace
hist radhlw if wave==2 & gender==1, subtitle(wave two 1996 males) color(sienna)
gr save radhlw2m.gph, replace
hist radhlw if wave==2 & gender==2, subtitle(wave two 1996 females)
gr save radhlw2f.gph, replace
hist radhlw if wave==3 & gender==1, subtitle(wave three now males) color(sienna)
gr save radhlw3m.gph, replace
hist radhlw if wave==3 & gender==2, subtitle(wave three now females)
gr save radhlw3f.gph, replace
gr combine radhlw1m.gph radhlw1f.gph radhlw2m.gph radhlw2f.gph radhlw3m.gph radhlw3f.gph, col(2) title(Percent of radiaton impact on own health) ///
 subtitle(Distributional change over waves) 
graph save radhlwfm.gph, replace
graph export radhlwfm.emf, replace
* tab agegrp,gen(agegp)


/*

longplot radhlw wave, i(id) shake title(Radhlw by wave)
graph save radhlbyWave.gph, replace
graph export radhlbyWave.emf, replace
longplot radhlw wave, i(id) by(gender) shake title(Radhlw by wave by gender)
graph save radhlbyWaveGend.gph, replace
graph export radhlbyWaveGend.emf, replace



xtline radhlw if gender==1, title(Rad impctd hlth) ytitle(Male Radhlw)
gr save MaleRdhlthByWave.gph, replace
gr export MaleRdhlthByWave.emf, replace


xtline radhlw if gender==2 , title(Rad impctd hlth) ytitle(Female Radhlw)
gr save FemRdhlthByWave.gph, replace
gr export FemRdhlthByWave.emf, replace
*/
//  determining which sociodemographic covariates might be appropriate
numlabel, add
tab gender


numlabel, add
tab oblnow
gen Oblnow= 0 if oblnow==10
replace Oblnow=1 if oblnow==23
* tab marrw, gen(marstat)
label def on 0 "Kyiv" 1 "Zhytomyr"
label values Oblnow on

numlabel, add
tab Oblnow
loc xvarlist "agew gender Oblnow illw inc3w phlthw mhlthw dril1w"
xtregar radhlw  `xvarlist'
tab age 
xttab gender
xttab educ
xtregar radhlw agew
xtregar radhlw educa1-educa7
xtregar radhlw gender educa1-educa7
numlabel, add

gen sex = 0 if gender==1
replace sex = 1 if gender==2
tab sex
label define sx 0 "male" 1 "female"
label values sex sx
tab sex

// population averaged (pooled) panel regressions

 loc rhs "gender agew educa1-educa7 illw phlthw aborw"
 xtreg radhlw `rhs', be  
 xtreg radhlw `rhs'
 loc rhs "gender agew educa1-educa7 illw phlthw aborw"
 xtreg radhlw `rhs', fe  // this is equivalent to xtgee pa
 estimates store FE
 loc rhs "gender agew educa1-educa7 illw phlthw aborw"
 xtreg radhlw `rhs', re 
 estimates store RE
 hausman FE RE, sigmamore
  loc rhs1 "agew educa1-educa7 illw phlthw aborw"
 // for all
 xtreg radhlw `rhs1', mle collinear nolog
   loc rhs1 "agew educa1-educa7 illw phlthw aborw"
 // males
 xtreg radhlw `rhs1' if gender==1, mle collinear nolog
 
 //females
 xtreg radhlw `rhs' if gender==2, mle collinear nolog
 // pooled OLS regression analysis 
 //for all
 regress radhlw agew gender illw phlthw aborw 
predict res2, residual
predict rstd2, rstandard
sum rstd2, detail
tab rstd   // reveals 1 negative outlier  t= -3.35  is this good or bad leveraged
 lvr2plot  // reveals some outlier
 predict cd, cooksd
 sum cd, detail
sktest res2  // normality tests
swilk res2   // residual normality test
estat imtest  //  het and normality test
estat hettest   // heteroskedasticity test
estat ovtest    // specification test of J. Ramsey
estat vif   // collinearity test 

 
 //for males  // insufficient obs for male to test
regress radhlw agew gender illw phlthw aborw if gender == 1
capture predict res1, residual
sktest res1  // normality tests
swilk res1   // residual normality test
estat imtest  //  het and normality test
estat hettest   // heteroskedasticity test
estat ovtest    // specification test of J. Ramsey
estat vif   // collinearity test 

// for females
regress radhlw agew illw phlthw aborw if gender == 2
predict res1f, residual
sktest res1  // normality tests
swilk res1   // residual normality test
estat imtest  //  het and normality test
estat hettest   // heteroskedasticity test
estat ovtest    // specification test of J. Ramsey
estat vif   // collinearity test 

sort id wave
xtset id wave

tab wave
// serial correlation across waves 
// demonstrated below:


correlate radhlw l.radhlw l2.radhlw
// suggests ar1 or ar2 or exchangeable working correlation structure



// pooled OLS regression with robust std errors
//for all
regress radhlw agew gender illw phlthw aborw, vce(robust)
// for males 
regress radhlw agew illw phlthw aborw if gender==1, vce(robust) 
//  for females 
regress radhlw agew illw phlthw aborw if gender==2, vce(robust)

// pooled OLS regression with robust std errors
// for all
reg radhlw agew gender illw phlthw aborw, vce(cluster id)
// for males
reg radhlw agew illw phlthw aborw if gender==1, vce(cluster id)
// for females
reg radhlw agew illw phlthw aborw if gender==2, vce(cluster id)
// pooled OLS regression with robust std errors


// tab emplw, gen(emplymt)
// order emplymt1-emplymt6, after(emplw)

estimates clear
//  some panel regression model comparison
xtreg radhlw gender agew illw phlthw, fe   
 est store reg5fe
xtreg radhlw agew gender illw phlthw , fe 
 est store reg4fe
xtreg radhlw agew gender illw phlthw educa3-educa8, re theta
 est store reg5edfe
xtreg radhlw agew gender illw phlthw emplymt2-emplymt6,fe
 est store reg5empfe
xtreg radhlw agew gender illw phlthw aborw, vce(bootstrap) nodots
  est store reg5bs

  est stats _all      // reg5fe and reg4fe are equally good and the best of this group

  
  
// in suffficient obs for males to test  
  
// for all
xtreg radhlw agew gender illw phlthw aborw, vce(robust)
  est store reg5illrob
xtreg radhlw agew gender illw phlthw aborw, be
  est store reg5be
est stats _all
// for males
xtreg radhlw agew illw phlthw aborw if gender==1, vce(robust)
  est store reg5illrobm
xtreg radhlw agew illw phlthw aborw if gender==1, be
  est store reg5bem
est stats _all
//  for females
xtreg radhlw agew illw phlthw aborw if gender==2, vce(robust)
  est store reg5illrobf
xtreg radhlw agew  illw phlthw aborw if gender==2, be
  est store reg5bef
est stats _all

est clear
//   Hausman test for fixed effects
xtreg radhlw agew gender illw phlthw aborw, fe 
estimates store FE
xtreg radhlw agew gender illw phlthw aborw, re theta
estimates store RE
hausman FE RE, sigmamore   // the errors are correlated with the predictors so we should be using a fixed effects model for covariates
                           //  but this assumes that the errors of the re are iid, which they are not
						    //  therefore, we should use the robust Hausman test


 est clear
xtreg radhlw agew gender illw phlthw aborw, mle nolog
     est store reg5paMle
xtreg radhlw agew gender illw phlthw aborw, pa nolog
     est store reg5paOLS
xtreg radhlw agew gender illw phlthw aborw, pa corr(unstructured) nolog
     est store reg5paUnstr
xtreg radhlw agew gender illw phlthw aborw, pa corr(exchangeable) nolog // better than unstructured
     est store reg5paExch
xtreg radhlw agew gender illw phlthw aborw, pa corr(ar 2) vce(robust) nolog
     est store reg5paAR2rob
est stats _all

est clear
// panel autoregression with ar correlated errors
xtregar radhlw age gender illw phlthw emplymt2-emplymt6, rhotype(tscorr) twostep fe lbi
  est store regar5emptscorr2stpfe    
// generalized least squares estimation of panel data
xtgls  radhlw agew gender illw phlthw aborw, corr(ar1)
   est store gls5ar1
xtgls radhlw agew gender illw phlthw aborw, panels(heteroskedastic) corr(ar1)
   est store gls5hetar1
est stats _all

  
//  generalized estimating equations
 loc rhs "gender agew educa3-educa7 illw phlthw aborw"
 xtgee radhlw agew gender illw phlthw aborw, fam(gaussian) link(id)
   gen GeeAIC1 = -2*e(deviance) + (2*e(df_m)+1)
 xtgee radhlw agew gender illw phlthw aborw, fam(gamma) link(power -1)
   gen  GeeAIC2 = -2*e(deviance) + (2*e(df_m)+1)
 xtgee radhlw agew gender illw phlthw aborw, fam(gamma) link(log)
   gen GeeAIC3 = -2*e(deviance) + (2*e(df_m)+1)
xtgee radhlw gender agew educa1-educa7 illw phlthw, ///
  fam(gaussian) link(id) corr(exchangeable) vce(robust)
   gen GeeAIC4 = -2*e(deviance) + (2*e(df_m)+1)
xtgee radhlw gender educa1-educa7 illw phlthw, ///
  fam(gaussian) link(id) corr(exchangeable) vce(robust)
  gen GeeAIC5 = -2*e(deviance) + (2*e(df_m)+1)
 forvalues i=1/5{
 display "GeeAIC`i' = ",GeeAIC`i'
 
 }
 display "Model 4 Gaussian identity link exchangeable correlation matrix is best"

 
 capture drop bic1- bic7  
 // comparing generalized linear models   
set more off 
glm radhlw agew gender illw phlthw aborw, fam(gaussian) link(id) nolog irls
  gen bic1 = e(bic)
// caution: bootstrapped options should include cluster(id) if there is clustering by id as there is here

glm radhlw agew gender illw phlthw aborw, fam(gaussian) link(id) vce(bootstrap,reps(500) nodots seed(202)) nolog 
  gen bic2 = e(bic)
glm radhlw agew gender illw phlthw aborw, fam(gaussian) link(id) vce(bootstrap, reps(500) bca seed(20202) nodots) nolog
  gen bic3 = e(bic)
matrix list e(bias)
matrix list e(accel)
display e(aic)
glm radhlw agew gender illw phlthw aborw, fam(gaussian) link(id) vce(jacknife) nolog
  gen bic4  = e(bic)
glm radhlw agew gender illw phlthw aborw, fam(igaussian) link(power -2) nolog irls
   gen bic5 = e(bic)
glm radhlw agew gender illw phlthw aborw, fam(gamma) link(power -1) nolog irls
   gen bic6 = e(bic)
glm radhlw agew gender illw phlthw aborw, fam(gamma) link(log) nolog irls
   gen bic7 = e(bic)
glm radhlw agew gender illw phlthw aborw, fam(gamma) link(id) nolog irls
   gen bic8  = e(bic)
   
  display "Comparison of BIC of glm models"
   forvalues i=1/8 {
   display "BIC`i' = ",bic`i'
   }
  display "Model 5 is the best: Inverse Gaussian and link function = 1/sqrt"
glm radhlw agew gender illw phlthw aborw, fam(igaussian) link(power -2) nolog irls  


*********************************************************************************************************

xtmixed radhlw agew gender illw phlthw aborw || id:, mle


xttab radhlw
loc xvarlist "agew gender oblnow illw inc3w phlthw dril1w"
xtregar radhlw `xvarlist'
save chlonw6Bob, replace
label var defnw "% of nutritional problems considrered hazardous"
label var ecprw "% of economic problems considered hazardous"
label var polprw "% of political problems considered hazardous"
label var efradw "% effects of radiation considered hazardous"
label var airw "% of air and water pollution believed hazardous"
label var radw "Believed % of area believed to be contaminated now"
label var radchw "Believed % of pollution related to Chornobyl"
label var radtlw "Believed % of lifetime cumulative radiation exposure"
label var medw " Believed % of danger expressed in media"
label var radhlw "% own health was affected by Chornobyl radiation"
label var radfmw "% own family health affected by Chornobyl radiation"
*****************  Mixed Model Analysis   ********************************
foreach var of varlist whpel-whppa {
replace `var' = 0 if `var'==.
}

foreach var of varlist hp2work1-hp2vacatn {
replace `var' = 0 if `var'==.
}


// cluster robust std errors provided by the bootstrap
xtset id
bootstrap, reps(400) seed(1234321) bca cluster(id) nodots: xtmixed radhlw age gender Oblnow phlthw aborw kmacc kmwork || id :, mle covar(unstructured)
bootstrap, reps(400) seed(1234321) bca cluster(id) nodots: xtmixed radhlw age gender Oblnow phlthw aborw kmacc kmwork || id :, mle covar(exchangeable)
matrix list e(bias)
matrix define bias = e(bias)'
matrix list bias
matrix list e(accel)
bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: xtmixed radhlw agew gender Oblnow phlthw aborw|| id:, mle covar(exchangeable)
matrix list e(bias)
matrix define bias = e(bias)'
matrix list bias
matrix list e(accel)

xtmixed radhlw gender Oblnow phlthw dril1w inc3w aborw || id :
xtmixed radhlw gender agew Oblnow phlthw aborw || id :

//  we begin to test the scales now.  
//  we proceed from BSI possym-psychotocism globseve
//  to NHP  
//  then to Coping  CSprbslv CSsocspt CSavoid CSglobal
/*
bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: ///
   xtmixed radhlw agew age2 gender Oblnow phlthw aborw bsiglobsi ///
   bsisom bsioc bsidep bsiips bsianx  ///
   bsipar bsipsyc || id:, mle covar(exchangeable)
gen age2=age*age
label var age2 "age squared"

   
 
bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: ///
   xtmixed radhlw agew gender Oblnow phlthw aborw bsipsts ///
   bsiips || id:, mle covariance(exchangeable) 

 */  
   
//   we now add NHP components subscales plus part 2 components
   
   
  bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: ///
   xtmixed radhlw agew gender Oblnow phlthw aborw bsipsts ///
   bsiips || id:, mle covariance(exchangeable) 

   
   bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: ///
   xtmixed radhlw agew gender Oblnow phlthw aborw bsipsts ///
    hp2work1-hp2vacatn || id:, mle covariance(exchangeable)       // hp2hmcare only one signif.
   
 
   bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: ///     // too few obs to test any NHP but whpel
   xtmixed radhlw agew gender Oblnow phlthw aborw bsipsts ///         // whpel is not signif p=.941 so we drop it
    whpel-whppa || id:, mle covariance(exchangeable) 

	log close _all
	
log using FinalInterimModels, replace
   
//   we now add coping subscales                                     CSAvoid was ommitted by program so I do not include it here
   bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: ///
   xtmixed radhlw agew gender Oblnow phlthw aborw ///
        bsipsts 
		whpel hp2hmcare ///         
      CSglobal CSprbslv CSsocspt || id:, mle covariance(exchangeable)    // coping strategies  all CS are not significant so we drop them
 
 
 // FINAL model
   bootstrap, reps(4000) seed(1234321) bca cluster(id) nodots: ///    
   xtmixed radhlw agew gender Oblnow phlthw aborw bsipsts whpel hp2hmcare ///         
    || id:, mle covariance(exchangeable) 

	log close _all
	
